PaginationView class

Inheritance

Constructors

PaginationView({required int totalPages, required int currentPage, required Function getData, double? radius, double? buttonHeight, int? bounceDuration, double? iconSize, double? textFontSize, double? spaceBetween, double? padding, double? margin, double? normalWidth, Color? selectedTextColor, Color? unSelectedTextColor, Color? firstButtonColor, Color? lastButtonColor, Color? middleButtonColor, Color? activeButtonColor, Color? prevAndNextButtonColor, Color? dotsColor, Key? key})

Properties

activeButtonColor Color?
final
bounceDuration int?
final
buttonHeight double?
final
currentPage int
getter/setter pair
dotsColor Color?
final
firstButtonColor Color?
final
getData Function
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
iconSize double?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lastButtonColor Color?
final
margin double?
final
middleButtonColor Color?
final
normalWidth double?
final
padding double?
final
prevAndNextButtonColor Color?
final
radius double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedTextColor Color?
final
spaceBetween double?
final
textFontSize double?
final
totalPages int
getter/setter pair
unSelectedTextColor Color?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<PaginationView>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited